@@ -8,7 +8,7 @@ from tornado import ioloop
 from tornado.concurrent import Future
 
 
-version_tuple = (0, 6)
+version_tuple = (0, 7)
 
 version = '.'.join(map(str, version_tuple))
 """Current version of Toro."""
@@ -713,6 +713,8 @@ class Semaphore(object):
             deadline relative to the current time.
         """
         queue_future = self.q.get(deadline)
+        if self.q.empty():
+            self._unlocked.clear()
         future = _ContextManagerFuture(queue_future, self.release)
         return future
 
